EVCControlMechanism
===================

.. automodule:: psyneulink.library.components.mechanisms.modulatory.control.evc.evccontrolmechanism
   :members:
   :private-members:
   :exclude-members: random, LinearCombination, Linear, Parameters
